#include <ESP8266WiFi.h>

const char* ssid     = "<<wifi ssid>>";                     // wifi ssid
const char* password = "<<wifi password>>";                 // wifi password
String auth          = "<<authentication>>";                // Authentication credentials Create a string from <email_address>:<API_Password> and encode it base64
                                                            // The sample: 
                                                            //    String auth = "dXNlcjpwYXNzd29yZA==" 
                                                            // is the encoding for "user:password"


char server[]  = "www.ic2pro.com";                          // Wiring Cloud host name www.ic2cloud.com
int port       = 80;                                        // port
String devId   = "111-222-333";                             // Device ID. CREATE YOUR OWN GUID; Use this http://www.guidgenerator.com/
                                                            // You can leave this 111-222-333 if this is your first project with IC2Cloud. 
                                                            // If you change it then you have to change the ID on your cloud device and
                                                            // on your mobile application

int motionStatus;                                           // cache current motion state
int motionPin = 4;                                          // pin used to read the PIR sensor
int ledPin = 2;                                             // pin used to show the motion status


void setup() {
  // initilize serial connection for debug
  Serial.begin(115200);
  delay(10);

  // setup GPIO pins
  pinMode(motionPin, INPUT);
  pinMode(ledPin,   OUTPUT);

  // Start connection to a WiFi network
  Serial.println();
  Serial.println();
  Serial.print("Connecting to ");
  Serial.println(ssid);
  
  WiFi.begin(ssid, password);
  
  while (WiFi.status() != WL_CONNECTED) {
    delay(500);
    Serial.print(".");
  }

  Serial.println("");
  Serial.println("WiFi connected");  
  Serial.println("IP address: ");
  Serial.println(WiFi.localIP());

  motionStatus = 0;
}

void sendEvent() {
    // send motion event to the wiring cloud at IC2Cloud platform
    Serial.print("connecting to ");
    Serial.println(server);
    
    // Use WiFiClient class to create TCP connections
    WiFiClient client;
    if (!client.connect(server, port)) {
      Serial.println("connection failed");
      return;
    }
    
    // Send motion signal to the server
    client.print("GET http://" + String(server) + ":" + String(port) + "/Wire/connector/set?id=" + devId + "&MOTION=YES HTTP/1.1\r\n" +
                 "Host: " + server + "\r\n" + 
                 "Authorization: Basic " + auth + "\r\n" +
                 "Connection: close\r\n\r\n");
    delay(10);
    
    // Read all the lines of the reply from server and print them to Serial
    while(client.available()){
      String line = client.readStringUntil('\r');
      Serial.print(line);
    }
    
    Serial.println();
    Serial.println("closing connection");
}

void loop() {
  delay(500);

  // read motion sensor
  int newStatus = digitalRead(motionPin);

  // if state changed from last reading then store new change and send signal if motion is detected 
  if(newStatus != motionStatus) {
    Serial.print("Status changed -> ");
    motionStatus = newStatus;  // cache new value for motion state
    Serial.println(motionStatus);
    if(motionStatus == 0)       // Motion sensor is normally in state 1 and transition to zero whenever motion is detected
      sendEvent();
  }
  
  // light up the led to get local feedback
  digitalWrite(ledPin, 1 - motionStatus);
}

